/*-
 * Copyright 2021 Adam Bieńkowski <donadigos159@gmail.com>
 *
 * This program is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see http://www.gnu.org/licenses/.
 */

public class AppEditor.AppInfoViewStack : Gtk.Stack {
    public signal void view_removed (AppInfoView view);
    public signal void duplicate_app (DesktopApp app);

    construct {
        transition_type = Gtk.StackTransitionType.SLIDE_UP_DOWN;
        transition_duration = 300;
        interpolate_size = true;

        var no_selected_view = new Granite.Widgets.AlertView (_("No Item Selected"), _("Select an application or start typing to edit one"), "edit-find-symbolic");
        no_selected_view.show_all ();
        add (no_selected_view);

        view_removed.connect (on_view_removed);
    }

    public AppInfoView? get_current_view () {
        return visible_child as AppInfoView;
    }

    public Gee.ArrayList<AppInfoView> get_unsaved_views () {
        var unsaved = new Gee.ArrayList<AppInfoView> ();

        List<unowned Gtk.Widget> children = get_children ();
        children.@foreach ((child) => {
            if (child is AppInfoView) {
                var app_info_view = (AppInfoView)child;
                if (app_info_view.get_changed ()) {
                    unsaved.add (app_info_view);
                }
            }
        });

        return unsaved;
    }

    public void show_app_info (DesktopApp desktop_app) {
        AppInfoView? widget = null;

        List<unowned Gtk.Widget> children = get_children ();
        children.@foreach ((child) => {
            if (child is AppInfoView) {
                var app_info_view = (AppInfoView)child;
                if (widget == null && desktop_app.compare (app_info_view.desktop_app)) {
                    widget = app_info_view;
                }
            }
        });

        if (widget == null) {
            widget = new AppInfoView (desktop_app);
            widget.removed.connect (() => view_removed (widget));
            widget.duplicate.connect (() => duplicate_app (desktop_app));
            add (widget);
        }

        widget.show_all ();
        visible_child = widget;
    }

    private void on_view_removed (AppInfoView view) {
        remove (view);
    }
}
